// Generated by dts-bundle-generator v5.9.0
/// <reference types="react" />
import { Action, AnyAction, Dispatch, Reducer, Store, StoreEnhancer } from 'redux';
export type ActionsQueue<ActionType extends Action> = ActionType[];
export interface UndoHistoryState<ActionType extends Action> {
	readonly undoQueue: ActionsQueue<ActionType>;
	readonly redoQueue: ActionsQueue<ActionType>;
}
declare enum DiagramMakerComponentsType {
	/**
	 * Used on context menus rendered by diagram maker.
	 * For internal use only.
	 */
	CONTEXT_MENU = "DiagramMaker.ContextMenu",
	/**
	 * Used on edges rendered by diagram maker.
	 * For internal use only.
	 */
	EDGE = "DiagramMaker.Edge",
	/**
	 * Used on edge badges rendered by diagram maker.
	 * For internal use only.
	 */
	EDGE_BADGE = "DiagramMaker.EdgeBadge",
	/**
	 * Used on potential edges rendered by diagram maker.
	 * For internal use only.
	 */
	POTENTIAL_EDGE = "DiagramMaker.PotentialEdge",
	/**
	 * Used on potential nodes being dragged currently by diagram maker.
	 * Also used by consumers on the drag targets for potential nodes.
	 */
	POTENTIAL_NODE = "DiagramMaker.PotentialNode",
	/**
	 * Used on nodes rendered by diagram maker.
	 * For internal use only.
	 */
	NODE = "DiagramMaker.Node",
	/**
	 * Used on node connectors displayed by diagram maker.
	 * Can also be used within the node to make the entire node,
	 * or parts of the node DOM be droppable for completion of edge creation
	 * or draggable for starting edge creation.
	 */
	NODE_CONNECTOR = "DiagramMaker.Connector",
	/**
	 * Used on panels rendered by diagram maker.
	 * For internal use only.
	 */
	PANEL = "DiagramMaker.Panel",
	/**
	 * Used as a drag handle on panels rendered by diagram maker.
	 * If you give an element this data-type in the panel render callback
	 * dragging this element will drag the panel
	 */
	PANEL_DRAG_HANDLE = "DiagramMaker.PanelDragHandle",
	/**
	 * Used on selection marquee rendered by diagram maker in select mode.
	 * For internal use only.
	 */
	SELECTION_MARQUEE = "DiagramMaker.SelectionMarquee",
	/**
	 * Used on top level container rendered by diagram maker.
	 * For internal use only.
	 */
	VIEW = "DiagramMaker.View",
	/**
	 * Used on workspace rendered by diagram maker.
	 * For internal use only.
	 */
	WORKSPACE = "DiagramMaker.Workspace"
}
export declare const DiagramMakerComponents: {
	CONTEXT_MENU: DiagramMakerComponentsType.CONTEXT_MENU;
	EDGE: DiagramMakerComponentsType.EDGE;
	EDGE_BADGE: DiagramMakerComponentsType.EDGE_BADGE;
	POTENTIAL_EDGE: DiagramMakerComponentsType.POTENTIAL_EDGE;
	POTENTIAL_NODE: DiagramMakerComponentsType.POTENTIAL_NODE;
	NODE: DiagramMakerComponentsType.NODE;
	NODE_CONNECTOR: DiagramMakerComponentsType.NODE_CONNECTOR;
	PANEL: DiagramMakerComponentsType.PANEL;
	PANEL_DRAG_HANDLE: DiagramMakerComponentsType.PANEL_DRAG_HANDLE;
	SELECTION_MARQUEE: DiagramMakerComponentsType.SELECTION_MARQUEE;
	VIEW: DiagramMakerComponentsType.VIEW;
	WORKSPACE: DiagramMakerComponentsType.WORKSPACE;
};
declare enum EdgeActionsType {
	/** Edge creation */
	EDGE_CREATE = "EDGE_CREATE",
	/** Edge deletion */
	EDGE_DELETE = "EDGE_DELETE",
	/** Edge selection */
	EDGE_SELECT = "EDGE_SELECT",
	/** Potential Edge drag start */
	EDGE_DRAG_START = "EDGE_DRAG_START",
	/** Potential Edge drag */
	EDGE_DRAG_END = "EDGE_DRAG_END",
	/** Potential Edge drag end */
	EDGE_DRAG = "EDGE_DRAG",
	/** Mouse enters edge */
	EDGE_MOUSE_OVER = "EDGE_MOUSE_OVER",
	/** Mouse leaves edge */
	EDGE_MOUSE_OUT = "EDGE_MOUSE_OUT"
}
export declare const EdgeActions: {
	EDGE_CREATE: EdgeActionsType.EDGE_CREATE;
	EDGE_DELETE: EdgeActionsType.EDGE_DELETE;
	EDGE_SELECT: EdgeActionsType.EDGE_SELECT;
	EDGE_DRAG_START: EdgeActionsType.EDGE_DRAG_START;
	EDGE_DRAG_END: EdgeActionsType.EDGE_DRAG_END;
	EDGE_DRAG: EdgeActionsType.EDGE_DRAG;
	EDGE_MOUSE_OVER: EdgeActionsType.EDGE_MOUSE_OVER;
	EDGE_MOUSE_OUT: EdgeActionsType.EDGE_MOUSE_OUT;
};
/** Action fired to select an edge */
export interface SelectEdgeAction extends Action {
	type: EdgeActionsType.EDGE_SELECT;
	payload: {
		/** ID of the edge that needs to be selected */
		id: string;
	};
}
/** Action fired to delete an edge */
export interface DeleteEdgeAction extends Action {
	type: EdgeActionsType.EDGE_DELETE;
	payload: {
		/** ID of the edge that needs to be deleted */
		id: string;
	};
}
/** Action fired to create an edge */
export interface CreateEdgeAction<EdgeType> extends Action {
	type: EdgeActionsType.EDGE_CREATE;
	payload: {
		/** ID of the new edge that needs to be created. Needs to be unique. */
		id: string;
		/** ID of the node from where this edge originates */
		src: string;
		/** ID of the node where this edge terminates */
		dest: string;
		/** Consumer data that needs to be added for this newly created edge. */
		consumerData?: EdgeType;
	};
}
/** Action fired to start dragging a potential edge */
export interface DragStartEdgeAction extends Action {
	type: EdgeActionsType.EDGE_DRAG_START;
	payload: {
		/** ID of the node from where this potential edge originates */
		id: string;
		/** Position where this potential edge terminates. Usually the cursor position. */
		position: Position;
	};
}
/** Action fired to end dragging a potential edge */
export interface DragEndEdgeAction extends Action {
	type: EdgeActionsType.EDGE_DRAG_END;
}
/** Action fired to update the termination position for a potential edge */
export interface DragEdgeAction extends Action {
	type: EdgeActionsType.EDGE_DRAG;
	payload: {
		/** Updated position where this potential edge should terminate. Usually the cursor position. */
		position: Position;
	};
}
/** Action fired when the mouse enters an edge */
export interface MouseOverAction extends Action {
	type: EdgeActionsType.EDGE_MOUSE_OVER;
	payload: {
		/** ID of the edge that is being hovered */
		id: string;
	};
}
/** Action fired when the mouse leaves an edge */
export interface MouseOutAction extends Action {
	type: EdgeActionsType.EDGE_MOUSE_OUT;
	payload: {
		/** ID of the edge that is being hovered */
		id: string;
	};
}
export declare type EdgeAction<EdgeType> = CreateEdgeAction<EdgeType> | SelectEdgeAction | DeleteEdgeAction | DragStartEdgeAction | DragEndEdgeAction | DragEdgeAction | MouseOverAction | MouseOutAction;
declare enum EditorActionsType {
	/** Set the mode for the editor. */
	SET_EDITOR_MODE = "SET_EDITOR_MODE",
	/** Show the context menu. */
	SHOW_CONTEXT_MENU = "SHOW_CONTEXT_MENU",
	/** Hide the context menu. */
	HIDE_CONTEXT_MENU = "HIDE_CONTEXT_MENU",
	/** Show the selection marquee. */
	SHOW_SELECTION_MARQUEE = "SHOW_SELECTION_MARQUEE",
	/** Update the selection marquee. */
	UPDATE_SELECTION_MARQUEE = "UPDATE_SELECTION_MARQUEE",
	/** Hide the selection marquee. */
	HIDE_SELECTION_MARQUEE = "HIDE_SELECTION_MARQUEE",
	/** Focus the given node */
	FOCUS_NODE = "FOCUS_NODE",
	/** Fits all nodes into view */
	FIT = "FIT"
}
export declare const EditorActions: {
	SET_EDITOR_MODE: EditorActionsType.SET_EDITOR_MODE;
	SHOW_CONTEXT_MENU: EditorActionsType.SHOW_CONTEXT_MENU;
	HIDE_CONTEXT_MENU: EditorActionsType.HIDE_CONTEXT_MENU;
	SHOW_SELECTION_MARQUEE: EditorActionsType.SHOW_SELECTION_MARQUEE;
	UPDATE_SELECTION_MARQUEE: EditorActionsType.UPDATE_SELECTION_MARQUEE;
	HIDE_SELECTION_MARQUEE: EditorActionsType.HIDE_SELECTION_MARQUEE;
	FOCUS_NODE: EditorActionsType.FOCUS_NODE;
	FIT: EditorActionsType.FIT;
};
/** Action fired to set the mode for the editor */
export interface SetEditorModeAction extends Action {
	type: EditorActionsType.SET_EDITOR_MODE;
	payload: {
		/** Requested mode for the editor */
		mode: EditorModeType;
	};
}
/** Action fired to show the context menu */
export interface ShowContextMenuAction extends Action {
	type: EditorActionsType.SHOW_CONTEXT_MENU;
	payload: {
		/** Position to render the context menu */
		position: Position;
		/** Type of UI Element to show the context menu for. */
		targetType: DiagramMakerComponentsType;
		/** ID of the UI Element in case it was a node, edge or a panel. */
		targetId?: string;
	};
}
/** Action fired to hide the context menu */
export interface HideContextMenuAction extends Action {
	type: EditorActionsType.HIDE_CONTEXT_MENU;
}
/** Action fired to show the selection marquee */
export interface ShowSelectionMarqueeAction extends Action {
	type: EditorActionsType.SHOW_SELECTION_MARQUEE;
	payload: {
		/**
		 * Position to anchor the selection marquee.
		 * Usually the position where mouse was clicked to start the selection.
		 */
		anchor: Position;
	};
}
/** Action fired to update the selection marquee */
export interface UpdateSelectionMarqueeAction extends Action {
	type: EditorActionsType.UPDATE_SELECTION_MARQUEE;
	payload: {
		/**
		 * Position to anchor the selection marquee.
		 * Usually the position where mouse was clicked to start the selection.
		 */
		anchor: Position;
		/** The diagonally opposite corner from the anchor. Usually the current mouse position. */
		position: Position;
	};
}
/** Action fired to hide the selection marquee */
export interface HideSelectionMarqueeAction extends Action {
	type: EditorActionsType.HIDE_SELECTION_MARQUEE;
}
/** Action fired to focus on a specific node */
export interface FocusNodeAction extends Action {
	type: EditorActionsType.FOCUS_NODE;
	payload: {
		/** ID of the node to focus */
		id: string;
		/** position of the node to focus */
		position: Position;
		/** size of the node to focus */
		size: Size;
		/** Width of fixed left panel */
		leftPanelWidth?: number;
		/** Width of fixed right panel */
		rightPanelWidth?: number;
	};
}
/** Action fired to fit all nodes into view */
export interface FitAction extends Action {
	type: EditorActionsType.FIT;
	payload: {
		/** Position & sizes of nodes that need to be fit into view */
		nodeRects: Rectangle[];
		/** Width of fixed left panel */
		leftPanelWidth?: number;
		/** Width of fixed right panel */
		rightPanelWidth?: number;
	};
}
export declare type EditorAction = SetEditorModeAction | ShowContextMenuAction | HideContextMenuAction | ShowSelectionMarqueeAction | UpdateSelectionMarqueeAction | HideSelectionMarqueeAction | FocusNodeAction | FitAction;
declare enum GlobalActionsType {
	/** Delete several items including nodes, edges together */
	DELETE_ITEMS = "DELETE_ITEMS",
	/** Create several items including nodes, edges together */
	CREATE_ITEMS = "CREATE_ITEMS"
}
export declare const GlobalActions: {
	DELETE_ITEMS: GlobalActionsType.DELETE_ITEMS;
	CREATE_ITEMS: GlobalActionsType.CREATE_ITEMS;
};
/** Action fired to delete items */
export interface DeleteItemsAction extends Action {
	type: GlobalActionsType.DELETE_ITEMS;
	payload: {
		/** IDs of nodes to delete */
		nodeIds: string[];
		/** IDs of edges to delete */
		edgeIds: string[];
	};
}
/** Action fired to create items */
export interface CreateItemsAction<NodeType, EdgeType> extends Action {
	type: GlobalActionsType.CREATE_ITEMS;
	payload: {
		/** Node objects with all node info to create */
		nodes: DiagramMakerNode<NodeType>[];
		/** Edge objects with all edge info to create */
		edges: DiagramMakerEdge<EdgeType>[];
	};
}
export declare type GlobalAction<NodeType, EdgeType> = DeleteItemsAction | CreateItemsAction<NodeType, EdgeType>;
declare enum LayoutType {
	/** Layout used for heirarchical graphs. Used for tree type graph structures. */
	HIERARCHICAL = "Hierarchical",
	/** Layout used for flow digrams. */
	WORKFLOW = "Workflow"
}
export declare const Layout: {
	HIERARCHICAL: LayoutType.HIERARCHICAL;
	WORKFLOW: LayoutType.WORKFLOW;
};
export interface HierarchicalLayoutConfig {
	layoutType: LayoutType.HIERARCHICAL;
	/**
	 * List of nodes that must remain their positions.
	 * All other nodes are arranged around these fixed nodes.
	 */
	fixedNodeIds: string[];
	/**
	 * Minimal distance between two nodes.
	 */
	distanceMin: number;
	/**
	 * Maximal distance between two nodes.
	 * Defaults to `3 * distanceMin`.
	 */
	distanceMax?: number;
	/**
	 * Number from 0.0 to 1.0 representing how fast
	 * the distance between two nodes declines with each layer.
	 *
	 *   `0.0` means it will always remain `distanceMax`
	 *
	 *   `1.0` means it will jump and stay at `distanceMin`
	 *         starting from the second layer.
	 *
	 * Defaults to `0.3`.
	 */
	distanceDeclineRate?: number;
	/**
	 * Angle of gravity in radians.
	 *
	 *   `0.0` is rightward direction.
	 *
	 *   `Math.PI * 0.5` is upward direction.
	 *
	 * Defaults to `Math.PI * 1.5` (downward).
	 */
	gravityAngle?: number;
	/**
	 * Strength of gravity.
	 *
	 *   `0.0` disables the gravity.
	 *
	 *   `1.0` means that nodes push each other away
	 *         with the equal force as gravity pulls them towards `gravityAngle`.
	 *
	 *   `2.0` means that gravity is twice as strong as nodes repulsion.
	 *
	 * Defaults to `0.0`.
	 */
	gravityStrength?: number;
}
declare enum WorkflowLayoutDirectionType {
	/** Flow goes from top to bottom */
	TOP_BOTTOM = "TopBottom",
	/** Flow goes from bottom to top */
	BOTTOM_TOP = "BottomTop",
	/** Flow goes from left to right */
	LEFT_RIGHT = "LeftRight",
	/** Flow goes from right to left */
	RIGHT_LEFT = "RightLeft"
}
export declare const WorkflowLayoutDirection: {
	TOP_BOTTOM: WorkflowLayoutDirectionType.TOP_BOTTOM;
	BOTTOM_TOP: WorkflowLayoutDirectionType.BOTTOM_TOP;
	LEFT_RIGHT: WorkflowLayoutDirectionType.LEFT_RIGHT;
	RIGHT_LEFT: WorkflowLayoutDirectionType.RIGHT_LEFT;
};
export interface WorkflowLayoutConfig {
	layoutType: LayoutType.WORKFLOW;
	/**
	 * Direction of the workflow.
	 */
	direction: WorkflowLayoutDirectionType;
	/**
	 * Minimal distance between two nodes.
	 */
	distanceMin: number;
	/**
	 * When provided, the position of `fixedNodeId` will remain the same after layout.
	 * All other nodes will be layed out around this node.
	 *
	 * If not provided, the graph will be moved to top-left corner of the canvas.
	 */
	fixedNodeId?: string;
}
export declare type LayoutConfig = HierarchicalLayoutConfig | WorkflowLayoutConfig;
declare enum LayoutActionsType {
	/** Layout the nodes using auto layout */
	LAYOUT = "LAYOUT"
}
export declare const LayoutActions: {
	LAYOUT: LayoutActionsType.LAYOUT;
};
export interface LayoutAction extends Action {
	type: LayoutActionsType.LAYOUT;
	payload: LayoutConfig;
}
declare enum NodeActionsType {
	NODE_CREATE = "NODE_CREATE",
	NODE_DELETE = "NODE_DELETE",
	NODE_SELECT = "NODE_SELECT",
	NODE_DRAG_START = "NODE_DRAG_START",
	NODE_DRAG_END = "NODE_DRAG_END",
	NODE_DRAG = "NODE_DRAG",
	NODE_LAYOUT = "NODE_LAYOUT",
	POTENTIAL_NODE_DRAG_START = "POTENTIAL_NODE_DRAG_START",
	POTENTIAL_NODE_DRAG = "POTENTIAL_NODE_DRAG",
	POTENTIAL_NODE_DRAG_END = "POTENTIAL_NODE_DRAG_END"
}
export declare const NodeActions: {
	NODE_CREATE: NodeActionsType.NODE_CREATE;
	NODE_DELETE: NodeActionsType.NODE_DELETE;
	NODE_SELECT: NodeActionsType.NODE_SELECT;
	NODE_DRAG_START: NodeActionsType.NODE_DRAG_START;
	NODE_DRAG_END: NodeActionsType.NODE_DRAG_END;
	NODE_DRAG: NodeActionsType.NODE_DRAG;
	NODE_LAYOUT: NodeActionsType.NODE_LAYOUT;
	POTENTIAL_NODE_DRAG_START: NodeActionsType.POTENTIAL_NODE_DRAG_START;
	POTENTIAL_NODE_DRAG: NodeActionsType.POTENTIAL_NODE_DRAG;
	POTENTIAL_NODE_DRAG_END: NodeActionsType.POTENTIAL_NODE_DRAG_END;
};
/** Action fired to create a new node */
export interface CreateNodeAction<NodeType> extends Action {
	type: NodeActionsType.NODE_CREATE;
	payload: {
		/** ID for the new node that needs to be created. Needs to be unique. */
		id: string;
		/** type ID of the new node. Picked up from the potential node that was used to create this node. */
		typeId: string;
		/** Position where the new node will be created. */
		position: Position;
		/** Size of the new node */
		size: Size;
		/** Consumer data that needs to be added for the newly created node. */
		consumerData?: NodeType;
	};
}
/** Action fired when a new potential node starts being dragged */
export interface DragStartPotentialNodeAction extends Action {
	type: NodeActionsType.POTENTIAL_NODE_DRAG_START;
	payload: {
		/**
		 * type ID of the new node that will be created if this is dropped on the workspace.
		 * Picked up from the potential node that was used to create this potential node.
		 */
		typeId: string;
		/** Current position of the potential node */
		position: Position;
		/** Size for the node that will be created if this is dropped on the workspace. */
		size: Size;
	};
}
/** Action fired to update the position for a potential node */
export interface DragPotentialNodeAction extends Action {
	type: NodeActionsType.POTENTIAL_NODE_DRAG;
	payload: {
		/** Updated position for the potential node */
		position: Position;
		/** A Rectangle representing the workspace */
		workspaceRectangle: Rectangle;
	};
}
/** Action fired to end dragging the potential node */
export interface DragEndPotentialNodeAction extends Action {
	type: NodeActionsType.POTENTIAL_NODE_DRAG_END;
}
/** Action fired to select a node */
export interface SelectNodeAction extends Action {
	type: NodeActionsType.NODE_SELECT;
	payload: {
		/** ID of the node to select */
		id: string;
	};
}
/**
 * Action fired to delete a node.
 * Please note that this doesn't delete the connected edges
 * and may lead to edges that remain in state but are not rendered.
 */
export interface DeleteNodeAction extends Action {
	type: NodeActionsType.NODE_DELETE;
	payload: {
		/** ID of the node to delete */
		id: string;
	};
}
/** Action fired to start dragging a node */
export interface DragStartNodeAction extends Action {
	type: NodeActionsType.NODE_DRAG_START;
	payload: {
		/** ID of the node to start dragging for */
		id: string;
	};
}
/** Action fired to end dragging a node */
export interface DragEndNodeAction extends Action {
	type: NodeActionsType.NODE_DRAG_END;
	payload: {
		/** ID of the node to end dragging for */
		id: string;
	};
}
/** Action fired to update the position for the node */
export interface DragNodeAction extends Action {
	type: NodeActionsType.NODE_DRAG;
	payload: {
		/** ID of the node to update position for */
		id: string;
		/** Updated position for the node */
		position: Position;
		workspaceRectangle: Rectangle;
		size: Size;
	};
}
export declare type NodeAction<NodeType> = SelectNodeAction | DeleteNodeAction | DragStartNodeAction | DragEndNodeAction | DragNodeAction | DragPotentialNodeAction | DragStartPotentialNodeAction | DragEndPotentialNodeAction | CreateNodeAction<NodeType>;
declare enum PanelActionsType {
	/** Start dragging a panel */
	PANEL_DRAG_START = "PANEL_DRAG_START",
	/** Drag a panel */
	PANEL_DRAG = "PANEL_DRAG",
	/** Resize a panel */
	PANEL_RESIZE = "PANEL_RESIZE"
}
export declare const PanelActions: {
	PANEL_DRAG_START: PanelActionsType.PANEL_DRAG_START;
	PANEL_DRAG: PanelActionsType.PANEL_DRAG;
	PANEL_RESIZE: PanelActionsType.PANEL_RESIZE;
};
/** Action fired to resize a panel */
export interface ResizePanelAction extends Action {
	type: PanelActionsType.PANEL_RESIZE;
	payload: {
		/** ID of the panel to resize */
		id: string;
		/** Updated size of the panel */
		size: Size;
	};
}
/** Action fired to drag a panel */
export interface DragPanelAction extends Action {
	type: PanelActionsType.PANEL_DRAG;
	payload: {
		/** ID of the panel to drag */
		id: string;
		/** Updated position of the panel */
		position: Position;
		/** Size of diagram maker container */
		viewContainerSize: Size;
	};
}
/** Action fired on initial drag of panel */
export interface DragStartPanelAction extends Action {
	type: PanelActionsType.PANEL_DRAG_START;
	payload: {
		/** ID of the panel to drag */
		id: string;
	};
}
export declare type PanelAction = ResizePanelAction | DragPanelAction | DragStartPanelAction;
declare enum WorkspaceActionsType {
	/** Deselect all selected items */
	WORKSPACE_DESELECT = "WORKSPACE_DESELECT",
	/** Select all items in the workspace */
	WORKSPACE_SELECT_ALL = "WORKSPACE_SELECT_ALL",
	/** Move the workspace */
	WORKSPACE_DRAG = "WORKSPACE_DRAG",
	/** Zoom the workspacce */
	WORKSPACE_ZOOM = "WORKSPACE_ZOOM",
	/** Resize the container */
	WORKSPACE_RESIZE = "WORKSPACE_RESIZE",
	/** Resize the workspace canvas */
	WORKSPACE_CANVAS_RESIZE = "WORKSPACE_CANVAS_RESIZE",
	/** Resets the zoom */
	WORKSPACE_RESET_ZOOM = "WORKSPACE_RESET_ZOOM"
}
export declare const WorkspaceActions: {
	WORKSPACE_DESELECT: WorkspaceActionsType.WORKSPACE_DESELECT;
	WORKSPACE_SELECT_ALL: WorkspaceActionsType.WORKSPACE_SELECT_ALL;
	WORKSPACE_DRAG: WorkspaceActionsType.WORKSPACE_DRAG;
	WORKSPACE_ZOOM: WorkspaceActionsType.WORKSPACE_ZOOM;
	WORKSPACE_RESIZE: WorkspaceActionsType.WORKSPACE_RESIZE;
	WORKSPACE_CANVAS_RESIZE: WorkspaceActionsType.WORKSPACE_CANVAS_RESIZE;
	WORKSPACE_RESET_ZOOM: WorkspaceActionsType.WORKSPACE_RESET_ZOOM;
};
/** Action fired to deselect all items */
export interface DeselectAction extends Action {
	type: WorkspaceActionsType.WORKSPACE_DESELECT;
}
/** Action fired to select all items */
export interface SelectAllAction extends Action {
	type: WorkspaceActionsType.WORKSPACE_SELECT_ALL;
}
/** Action fired to move the worksapce around */
export interface DragWorkspaceAction extends Action {
	type: WorkspaceActionsType.WORKSPACE_DRAG;
	payload: {
		/** Updated position for the workspace */
		position: Position;
	};
}
/** Action fired to zoom the workspace */
export interface ZoomWorkspaceAction extends Action {
	type: WorkspaceActionsType.WORKSPACE_ZOOM;
	payload: {
		/**
		 * Incremental zoom to change the workspace scale by.
		 * Positive means zooming in. Negative means zooming out.
		 */
		zoom: number;
		/**
		 * The zoom origin. Usually the cursor position.
		 */
		position: Position;
	};
}
/** Action fired to resize the container */
export interface ResizeWorkspaceAction extends Action {
	type: WorkspaceActionsType.WORKSPACE_RESIZE;
	payload: {
		/** New container size that the workspace is rendering in. */
		containerSize: Size;
	};
}
/** Action fired to resize the workspace canvas */
export interface ResizeWorkspaceCanvasAction extends Action {
	type: WorkspaceActionsType.WORKSPACE_CANVAS_RESIZE;
	payload: {
		/** New canvas size of the workspace */
		canvasSize: Size;
	};
}
/** Action fired to reset the zoom level for the workspace */
export interface WorkspaceResetZoomAction extends Action {
	type: WorkspaceActionsType.WORKSPACE_RESET_ZOOM;
}
export declare type WorkspaceAction = DeselectAction | DragWorkspaceAction | ResizeWorkspaceCanvasAction | ResizeWorkspaceAction | SelectAllAction | ZoomWorkspaceAction | WorkspaceResetZoomAction;
export declare const DiagramMakerActions: {
	LAYOUT: import("diagramMaker/state/layout/layoutActions").LayoutActionsType.LAYOUT;
	DELETE_ITEMS: import("diagramMaker/state/global/globalActions").GlobalActionsType.DELETE_ITEMS;
	CREATE_ITEMS: import("diagramMaker/state/global/globalActions").GlobalActionsType.CREATE_ITEMS;
	SET_EDITOR_MODE: import("diagramMaker/state/editor/editorActions").EditorActionsType.SET_EDITOR_MODE;
	SHOW_CONTEXT_MENU: import("diagramMaker/state/editor/editorActions").EditorActionsType.SHOW_CONTEXT_MENU;
	HIDE_CONTEXT_MENU: import("diagramMaker/state/editor/editorActions").EditorActionsType.HIDE_CONTEXT_MENU;
	SHOW_SELECTION_MARQUEE: import("diagramMaker/state/editor/editorActions").EditorActionsType.SHOW_SELECTION_MARQUEE;
	UPDATE_SELECTION_MARQUEE: import("diagramMaker/state/editor/editorActions").EditorActionsType.UPDATE_SELECTION_MARQUEE;
	HIDE_SELECTION_MARQUEE: import("diagramMaker/state/editor/editorActions").EditorActionsType.HIDE_SELECTION_MARQUEE;
	FOCUS_NODE: import("diagramMaker/state/editor/editorActions").EditorActionsType.FOCUS_NODE;
	FIT: import("diagramMaker/state/editor/editorActions").EditorActionsType.FIT;
	EDGE_CREATE: import("diagramMaker/state/edge/edgeActions").EdgeActionsType.EDGE_CREATE;
	EDGE_DELETE: import("diagramMaker/state/edge/edgeActions").EdgeActionsType.EDGE_DELETE;
	EDGE_SELECT: import("diagramMaker/state/edge/edgeActions").EdgeActionsType.EDGE_SELECT;
	EDGE_DRAG_START: import("diagramMaker/state/edge/edgeActions").EdgeActionsType.EDGE_DRAG_START;
	EDGE_DRAG_END: import("diagramMaker/state/edge/edgeActions").EdgeActionsType.EDGE_DRAG_END;
	EDGE_DRAG: import("diagramMaker/state/edge/edgeActions").EdgeActionsType.EDGE_DRAG;
	EDGE_MOUSE_OVER: import("diagramMaker/state/edge/edgeActions").EdgeActionsType.EDGE_MOUSE_OVER;
	EDGE_MOUSE_OUT: import("diagramMaker/state/edge/edgeActions").EdgeActionsType.EDGE_MOUSE_OUT;
	WORKSPACE_DESELECT: import("diagramMaker/state/workspace/workspaceActions").WorkspaceActionsType.WORKSPACE_DESELECT;
	WORKSPACE_SELECT_ALL: import("diagramMaker/state/workspace/workspaceActions").WorkspaceActionsType.WORKSPACE_SELECT_ALL;
	WORKSPACE_DRAG: import("diagramMaker/state/workspace/workspaceActions").WorkspaceActionsType.WORKSPACE_DRAG;
	WORKSPACE_ZOOM: import("diagramMaker/state/workspace/workspaceActions").WorkspaceActionsType.WORKSPACE_ZOOM;
	WORKSPACE_RESIZE: import("diagramMaker/state/workspace/workspaceActions").WorkspaceActionsType.WORKSPACE_RESIZE;
	WORKSPACE_CANVAS_RESIZE: import("diagramMaker/state/workspace/workspaceActions").WorkspaceActionsType.WORKSPACE_CANVAS_RESIZE;
	WORKSPACE_RESET_ZOOM: import("diagramMaker/state/workspace/workspaceActions").WorkspaceActionsType.WORKSPACE_RESET_ZOOM;
	PANEL_DRAG_START: import("diagramMaker/state/panel/panelActions").PanelActionsType.PANEL_DRAG_START;
	PANEL_DRAG: import("diagramMaker/state/panel/panelActions").PanelActionsType.PANEL_DRAG;
	PANEL_RESIZE: import("diagramMaker/state/panel/panelActions").PanelActionsType.PANEL_RESIZE;
	NODE_CREATE: import("diagramMaker/state/node/nodeActions").NodeActionsType.NODE_CREATE;
	NODE_DELETE: import("diagramMaker/state/node/nodeActions").NodeActionsType.NODE_DELETE;
	NODE_SELECT: import("diagramMaker/state/node/nodeActions").NodeActionsType.NODE_SELECT;
	NODE_DRAG_START: import("diagramMaker/state/node/nodeActions").NodeActionsType.NODE_DRAG_START;
	NODE_DRAG_END: import("diagramMaker/state/node/nodeActions").NodeActionsType.NODE_DRAG_END;
	NODE_DRAG: import("diagramMaker/state/node/nodeActions").NodeActionsType.NODE_DRAG;
	NODE_LAYOUT: import("diagramMaker/state/node/nodeActions").NodeActionsType.NODE_LAYOUT;
	POTENTIAL_NODE_DRAG_START: import("diagramMaker/state/node/nodeActions").NodeActionsType.POTENTIAL_NODE_DRAG_START;
	POTENTIAL_NODE_DRAG: import("diagramMaker/state/node/nodeActions").NodeActionsType.POTENTIAL_NODE_DRAG;
	POTENTIAL_NODE_DRAG_END: import("diagramMaker/state/node/nodeActions").NodeActionsType.POTENTIAL_NODE_DRAG_END;
};
export declare type DiagramMakerAction<NodeType, EdgeType> = NodeAction<NodeType> | WorkspaceAction | PanelAction | EdgeAction<EdgeType> | GlobalAction<NodeType, EdgeType> | EditorAction | LayoutAction;
export interface Position {
	x: number;
	y: number;
}
export interface Size {
	width: number;
	height: number;
}
declare enum EditorModeType {
	/**
	 * Allows the workspace to be dragged to pan the visible area across the window.
	 */
	DRAG = "Drag",
	/**
	 * Prevents UI interactions other than panning and zooming the workspace.
	 */
	READ_ONLY = "ReadOnly",
	/**
	 * Allows selection of multiple nodes with a rectangular marquee.
	 */
	SELECT = "Select"
}
export declare const EditorMode: {
	DRAG: EditorModeType.DRAG;
	READ_ONLY: EditorModeType.READ_ONLY;
	SELECT: EditorModeType.SELECT;
};
export interface Rectangle {
	position: Position;
	size: Size;
}
/** Interface for storing the state of the diagram maker workspace */
export interface DiagramMakerWorkspace {
	/**
	 * Denotes the pixel values that the workspace has been translated by on x & y axis
	 */
	readonly position: Position;
	/**
	 * Denotes the scale of the workspace, where 1 denotes natural scale.
	 * Smaller than 1 denotes that the workspace has been zoomed out.
	 * Greater than 1 denotes that the workspace has been zoomed in.
	 */
	readonly scale: number;
	/**
	 * Denotes the size of the workspace that the customer can move nodes around in.
	 * Every object within the workspace, i.e. nodes, edges, potential nodes stays within these bounds.
	 */
	readonly canvasSize: Size;
	/**
	 * Denotes the size of the container diagram maker is rendered in.
	 * To update due to window resizing, or panels outside diagram maker shifting content,
	 * call the `updateContainer` API.
	 */
	readonly viewContainerSize: Size;
}
declare enum PositionAnchorType {
	/** Top Left edge of the container that diagram maker renders in */
	TOP_LEFT = "TopLeft",
	/** Top Right edge of the container that diagram maker renders in */
	TOP_RIGHT = "TopRight",
	/** Bottom Left edge of the container that diagram maker renders in */
	BOTTOM_LEFT = "BottomLeft",
	/** Bottom Right edge of the container that diagram maker renders in */
	BOTTOM_RIGHT = "BottomRight"
}
export declare const PositionAnchor: {
	TOP_LEFT: PositionAnchorType.TOP_LEFT;
	TOP_RIGHT: PositionAnchorType.TOP_RIGHT;
	BOTTOM_LEFT: PositionAnchorType.BOTTOM_LEFT;
	BOTTOM_RIGHT: PositionAnchorType.BOTTOM_RIGHT;
};
/**
 * Interface for storing the state of a given diagram maker node.
 * @template NodeType - The type of data stored per node by the consumer.
 */
export interface DiagramMakerNode<NodeType> {
	/**
	 * Unique identifier for the node.
	 * Autogenerated for nodes newly created.
	 * Supplied for nodes already present when diagram maker initializes.
	 * In the case it is supplied, please ensure that this is unique.
	 */
	readonly id: string;
	/**
	 * Type of the node. Optional.
	 * References to the id present on the potential node when it was dragged in.
	 * Also useful to specify override connector placements, hiding specific connectors
	 * or providing the shape for boundary connector placements.
	 */
	readonly typeId?: string;
	/**
	 * Contains node data managed by diagram maker.
	 */
	readonly diagramMakerData: {
		/**
		 * Current position of the node w.r.t the workspace
		 */
		readonly position: Position;
		/**
		 * Current size of the node
		 */
		readonly size: Size;
		/**
		 * Denotes whether the node is currently selected.
		 */
		readonly selected?: boolean;
		/**
		 * Denotes whether the node is currently being dragged.
		 */
		readonly dragging?: boolean;
	};
	/** Contains data managed by the consumer */
	readonly consumerData?: NodeType;
}
/**
 * Interface for storing state of several diagram maker nodes.
 * @template NodeType - The type of data stored per node by the consumer.
 */
export interface DiagramMakerNodes<NodeType> {
	readonly [id: string]: DiagramMakerNode<NodeType>;
}
/** Interface for storing state of diagram maker potential node i.e. a new node being dragged onto the workspace */
export interface DiagramMakerPotentialNode {
	/** Type of the node. Mandatory for providing context during node creation */
	readonly typeId: string;
	/** Current position of the potential node w.r.t the workspace */
	readonly position: Position;
	/** Size of the potential node as detected via tha data attrs on the drag target or via the type config */
	readonly size: Size;
}
/**
 * Interface for storing state of a given diagram maker edge.
 * @template EdgeType - The type of data stored per edge by the consumer
 */
export interface DiagramMakerEdge<EdgeType> {
	/**
	 * Unique identifier for the edge.
	 * Autogenerated for edges newly created.
	 * Supplied for edges already present when diagram maker initializes.
	 * In the case it is supplied, please ensure that this is unique.
	 */
	readonly id: string;
	/**
	 * References the id for the node where this edge originates.
	 * Leads to inconsistencies if this refers to a node that doesnt exist.
	 */
	readonly src: string;
	/**
	 * References the id for the node where this edge ends.
	 * Leads to inconsistencies if this refers to a node that doesnt exist.
	 */
	readonly dest: string;
	/** Contains edge data managed by diagram maker */
	readonly diagramMakerData: {
		/** Denotes whether the edge is selected */
		readonly selected?: boolean;
	};
	/** Contains data managed by the consumer */
	readonly consumerData?: EdgeType;
}
/**
 * Interface for storing state of several diagram maker edges.
 * @template EdgeType - The type of data stored per edge by the consumer
 */
export interface DiagramMakerEdges<EdgeType> {
	readonly [id: string]: DiagramMakerEdge<EdgeType>;
}
/** Interface for storing state of diagram maker potential edge i.e. a new edge being drawn on the workspace */
export interface DiagramMakerPotentialEdge {
	/**
	 * References the id for the node where this edge originates.
	 * Leads to inconsistencies if this refers to a node that doesnt exist.
	 */
	readonly src: string;
	/**
	 * Current position where the potential edge is pointing.
	 * Usually refers to the cursor position relative to the workspace scale & position.
	 */
	readonly position: Position;
}
/** Interface for storing state of a diagram maker panel */
export interface DiagramMakerPanel {
	/**
	 * Unique identifier for the panel.
	 * Provided by the consumer.
	 * Used for referencing the render callback.
	 */
	readonly id: string;
	/**
	 * Current position of the panel in the view container.
	 * Please note that panels remain outside the workspace
	 * so are not affected by its scale & panning.
	 */
	readonly position: Position;
	/**
	 * Current size for the panel.
	 * Used for providing a container to render the panel content in.
	 */
	readonly size: Size;
	/**
	 * Position Anchor. Optional. Used for docking panels.
	 * When not specified, panels are assumed to be relative to Top Left corner of view container.
	 * When specified, position is assumed to be relative to the anchor.
	 */
	readonly positionAnchor?: PositionAnchorType;
	/**
	 * Denoted whether the panel is in undocking mode.
	 * Panel is in undocking mode when it was previously docked,
	 * is currently being dragged and is within the docking bounds.
	 */
	readonly undocking?: boolean;
}
/** Interface for storing state for several diagram maker panels */
export interface DiagramMakerPanels {
	readonly [id: string]: DiagramMakerPanel;
}
/** Interface for storing state for a diagram maker plugin */
export interface DiagramMakerPlugin {
	readonly data: any;
}
/** Interface for storing state for several diagram maker plugins */
export interface DiagramMakerPlugins {
	readonly [id: string]: DiagramMakerPlugin;
}
/** Interface for storing state for diagram maker context menu */
export interface DiagramMakerContextMenu {
	/**
	 * Current position of the context menu in the view container.
	 * Please note context menus are not part of the workspace
	 * so not affected by its scale & panning.
	 */
	readonly position: Position;
	/**
	 * Type of the object that the context menu is being displayed for.
	 * For example, node, edge, panel, workspace, etc.
	 */
	readonly targetType: DiagramMakerComponentsType;
	/**
	 * Unique identifier to identify the specific node or edge or panel.
	 * Absent for the workspace.
	 */
	readonly targetId?: string;
}
/** Interface for storing state for diagram maker selection marquee */
export interface DiagramMakerSelectionMarquee {
	/**
	 * Position where the user clicked to start the selection.
	 * This remains one of the 4 corners of the selections marquee
	 */
	readonly anchor: Position;
	/**
	 * Current position of the cursor.
	 */
	readonly position: Position;
}
/** Interface for storing state for diagram maker editor */
export interface DiagramMakerEditor {
	/**
	 * Current context menu state if one needs to be rendered currently.
	 */
	readonly contextMenu?: DiagramMakerContextMenu;
	/**
	 * Current mode of the editor.
	 */
	readonly mode: EditorModeType;
	/**
	 * Current selection marquee state if one needs to be rendered currently.
	 */
	readonly selectionMarquee?: DiagramMakerSelectionMarquee;
}
export interface DiagramMakerData<NodeType, EdgeType> {
	/** Current state for all nodes */
	readonly nodes: DiagramMakerNodes<NodeType>;
	/** Current state for all edges */
	readonly edges: DiagramMakerEdges<EdgeType>;
	/** Current state for all panels */
	readonly panels: DiagramMakerPanels;
	/** Current state for all plugins */
	readonly plugins?: DiagramMakerPlugins;
	/** Current state for diagram maker workspace */
	readonly workspace: DiagramMakerWorkspace;
	/** Current state for diagram maker potential node if one needs to be rendered currently */
	readonly potentialEdge?: DiagramMakerPotentialEdge | null;
	/** Current state for diagram maker potential edge if one needs to be rendered currently */
	readonly potentialNode?: DiagramMakerPotentialNode | null;
	/** Current state for diagram maker editor */
	readonly editor: DiagramMakerEditor;
	/** History of undoable actions */
	readonly undoHistory?: UndoHistoryState<DiagramMakerAction<NodeType, EdgeType>>;
}
export declare type ActionInterceptor<NodeType, EdgeType> = (action: Action, dispatch: Dispatch<Action>, getState: () => DiagramMakerData<NodeType, EdgeType>) => void;
declare enum ConnectorPlacementType {
	/**
	 * Allows edges to be start & end at the boundary of the node.
	 * This falls back to CENTERED if the shape is not known for any given node.
	 * Doesn't render connectors by default.
	 */
	BOUNDARY = "Boundary",
	/**
	 * Edges start & end at the geometric center of the node.
	 * Doesn't render connectors by default.
	 */
	CENTERED = "Centered",
	/**
	 * Edges start at the right edge & end at the left edge of node bounding box.
	 * Does render connectors by default.
	 */
	LEFT_RIGHT = "LeftRight",
	/**
	 * Edges start at the bottom edge & end at the top edge of node bounding box.
	 * Does render connectors by default.
	 */
	TOP_BOTTOM = "TopBottom"
}
export declare const ConnectorPlacement: {
	BOUNDARY: ConnectorPlacementType.BOUNDARY;
	CENTERED: ConnectorPlacementType.CENTERED;
	LEFT_RIGHT: ConnectorPlacementType.LEFT_RIGHT;
	TOP_BOTTOM: ConnectorPlacementType.TOP_BOTTOM;
};
export declare type BoundRenderCallback = (diagramMakerContainer: HTMLElement, consumerContainer?: HTMLElement | void) => (HTMLElement | undefined | void);
/**
 * This callback is called to cleanup event handlers for DOM rendered by the consumer
 * before diagram maker removes the DOM.
 * @callback DestroyCallback
 * @param diagramMakerContainer - The container in which consumer rendered some DOM.
 * @param consumerContainer - This is passed only if the consumer returned this in renderCallback.
 * Useful for Preact, where you need to provide the element within the container to diff against.
 * @returns {void}
 * @example <caption> Destroy callback when using React </caption>
 * (diagramMakerContainer: HTMLElement) => ReactDOM.unmountComponentAtNode(diagramMakerContainer)
 */
export declare type DestroyCallback = (diagramMakerContainer: HTMLElement, consumerContainer?: HTMLElement | void) => void;
/**
 * This callback is called to render context menu for elements with IDs like node, edge, panel.
 * @callback ContextMenuRenderCallbackWithId
 * @param id - The ID of the element which was clicked. Since, we have different callbacks for node, edge, panel,
 * it is assumed that the type of the element is known before hand.
 * @param diagramMakerContainer - The container in which the consumer renders the context menu.
 * This is an empty container with only the position set correctly.
 * Could diff against content already present in the container using React, Preact or any other VDOM.
 * @param consumerContainer - This is passed only if the consumer returned this in prior calls to this callback.
 * Useful for Preact, where you need to provide the element within the container to diff against.
 * @returns {HTMLElement | undefined | void} - HTMLElement in case of Preact, or void or undefined everywhere else.
 */
export declare type ContextMenuRenderCallbackWithId = (id: string | undefined, diagramMakerContainer: HTMLElement, consumerContainer?: HTMLElement | void) => (HTMLElement | undefined | void);
/**
 * This callback is called to render context menu for elements without IDs like workspace.
 * Since, we have different callbacks for node, edge, panel,
 * it is assumed that the type of the element is known before hand.
 * @callback ContextMenuRenderCallback
 * @param diagramMakerContainer - The container in which the consumer renders the context menu.
 * This is an empty container with only the position set correctly.
 * Could diff against content already present in the container using React, Preact or any other VDOM.
 * @param consumerContainer - This is passed only if the consumer returned this in prior calls to this callback.
 * Useful for Preact, where you need to provide the element within the container to diff against.
 * @returns {HTMLElement | undefined | void} - HTMLElement in case of Preact, or void or undefined everywhere else.
 */
export declare type ContextMenuRenderCallback = (diagramMakerContainer: HTMLElement, consumerContainer?: HTMLElement | void) => (HTMLElement | undefined | void);
/**
 * Object containing render callbacks for context menu.
 */
export interface ContextMenuRenderCallbacks {
	/**
	 * Render callback for context menu for node. Optional.
	 * @type {ContextMenuRenderCallbackWithId}
	 */
	node?: ContextMenuRenderCallbackWithId;
	/**
	 * Render callback for context menu for edge. Optional.
	 * @type {ContextMenuRenderCallbackWithId}
	 */
	edge?: ContextMenuRenderCallbackWithId;
	/**
	 * Render callback for context menu for panel. Optional.
	 * @type {ContextMenuRenderCallbackWithId}
	 */
	panel?: ContextMenuRenderCallbackWithId;
	/**
	 * Render callback for context menu for workspace. Optional.
	 * @type {ContextMenuRenderCallback}
	 */
	workspace?: ContextMenuRenderCallback;
}
/** Object containing callbacks for rendering & destroying various entities (like nodes, edges, panels, etc) */
export interface RenderCallbacks<NodeType, EdgeType> {
	/**
	 * Callback to cleanup DOM rendered by the consumer properly
	 * before diagram maker removes it.
	 * In case, consumers are using React or any other rendering framework,
	 * the framework attaches event handlers that if not removed correctly,
	 * could cause a memory leak.
	 * @type {DestroyCallback}
	 */
	destroy: DestroyCallback;
	/**
	 * Callback to render a badge centered within the edge.
	 * @param {DiagramMakerEdge<EdgeType>} - The object representing the current state of the edge
	 * for which the badge is being rendered.
	 * @param {HTMLElement} diagramMakerContainer - Container managed by diagram maker to render content in
	 * Could diff against content already present in the container using React, Preact or any other VDOM.
	 * @param {HTMLElement} consumerContainer - Container used by consumer to render. Optional.
	 * Useful only when using Preact, since Preact appends by default
	 * and needs an Element to diff against in the container.
	 * @returns {HTMLElement | undefined | void} - Element rendered by consumer when using Preact,
	 * or undefined or void everywhere else.
	 */
	edge?: (edge: DiagramMakerEdge<EdgeType>, diagramMakerContainer: HTMLElement, consumerContainer?: HTMLElement | void) => (HTMLElement | undefined | void);
	/**
	 * Callback to render a node.
	 * @param {DiagramMakerNode<NodeType>} - The object representing the current state of the node being rendered.
	 * @param {HTMLElement} diagramMakerContainer - Container managed by diagram maker to render content in
	 * Could diff against content already present in the container using React, Preact or any other VDOM.
	 * @param {HTMLElement} consumerContainer - Container used by consumer to render. Optional.
	 * Useful only when using Preact, since Preact appends by default
	 * and needs an Element to diff against in the container.
	 * @returns {HTMLElement | undefined | void} - Element rendered by consumer when using Preact,
	 * or undefined or void everywhere else.
	 */
	node: (node: DiagramMakerNode<NodeType>, diagramMakerContainer: HTMLElement, consumerContainer?: HTMLElement | void) => (HTMLElement | undefined | void);
	/**
	 * Callback to render a potential node. Optional. Only useful when user might be dragging new nodes out of a panel.
	 * @param {DiagramMakerPotentialNode} - The object representing the current state of the potential node
	 * being rendered.
	 * @param {HTMLElement} diagramMakerContainer - Container managed by diagram maker to render content in
	 * Could diff against content already present in the container using React, Preact or any other VDOM.
	 * @param {HTMLElement} consumerContainer - Container used by consumer to render. Optional.
	 * Useful only when using Preact, since Preact appends by default
	 * and needs an Element to diff against in the container.
	 * @returns {HTMLElement | undefined | void} - Element rendered by consumer when using Preact,
	 * or undefined or void everywhere else.
	 */
	potentialNode?: (node: DiagramMakerPotentialNode, diagramMakerContainer: HTMLElement, consumerContainer?: HTMLElement | void) => (HTMLElement | undefined | void);
	/** Object containing render callbacks for several panels keyed on panel name */
	panels: {
		/**
		 * Callback to render a panel.
		 * @param {DiagramMakerPanel} - The object representing the current state of the panel being rendered.
		 * @param {HTMLElement} diagramMakerContainer - Container managed by diagram maker to render content in
		 * Could diff against content already present in the container using React, Preact or any other VDOM.
		 * @param {HTMLElement} consumerContainer - Container used by consumer to render. Optional.
		 * Useful only when using Preact, since Preact appends by default
		 * and needs an Element to diff against in the container.
		 * @returns {HTMLElement | undefined | void} - Element rendered by consumer when using Preact,
		 * or undefined or void everywhere else.
		 */
		[name: string]: (panel: DiagramMakerPanel, state: DiagramMakerData<NodeType, EdgeType>, diagramMakerContainer: HTMLElement, consumerContainer?: HTMLElement | void) => (HTMLElement | undefined | void);
	};
	/**
	 * Object containing render callbacks for context menus for various targets. Optional.
	 * If provided, diagram maker will use these context menu render callbacks to show a context menu,
	 * and suppress the browser rendered context menu.
	 */
	contextMenu?: ContextMenuRenderCallbacks;
}
declare enum TypeForVisibleConnectorTypes {
	/** Render both input & output connectors. Default Behavior. */
	BOTH = "Both",
	/** Render only input connector. */
	INPUT_ONLY = "Input",
	/** Render only output connector. */
	OUTPUT_ONLY = "Output",
	/** Render none of the connectors. */
	NONE = "None"
}
export declare const VisibleConnectorTypes: {
	BOTH: TypeForVisibleConnectorTypes.BOTH;
	INPUT_ONLY: TypeForVisibleConnectorTypes.INPUT_ONLY;
	OUTPUT_ONLY: TypeForVisibleConnectorTypes.OUTPUT_ONLY;
	NONE: TypeForVisibleConnectorTypes.NONE;
};
declare enum ShapeType {
	/**
	 * Denotes a circle shaped node.
	 * Assumes that node width & height are equal
	 * and the radius is equal to half of each of them
	 */
	CIRCLE = "Circle",
	/**
	 * Denotes a rectangle shaped node.
	 * Node width & height can be different, but all angles are right.
	 */
	RECTANGLE = "Rectangle"
}
export declare const Shape: {
	CIRCLE: ShapeType.CIRCLE;
	RECTANGLE: ShapeType.RECTANGLE;
};
/** Interface for storing configuration for a given node type */
export interface DiagramMakerNodeTypeConfiguration {
	/**
	 * Size used if override not provided by data attrs for potential nodes using this type.
	 */
	size: Size;
	/**
	 * Used for overriding visible connectors for nodes using this type.
	 * This is useful only in case diagram maker renders connectors by default i.e. LEFT_RIGHT or TOP_BOTTOM.
	 */
	visibleConnectorTypes?: TypeForVisibleConnectorTypes;
	/**
	 * Used for overriding the connector placement for nodes using this type.
	 */
	connectorPlacementOverride?: ConnectorPlacementType;
	/**
	 * Used for providing shape for nodes using this type.
	 * Used in conjunction with BOUNDARY connector placement.
	 */
	shape?: ShapeType;
}
export interface DiagramMakerConfig<NodeType, EdgeType> {
	/**
	 * Optional configuration for diagram maker
	 */
	options?: {
		/**
		 * Connector placement. Determines how the edges are rendered.
		 * Also renders default connectors for some placement types.
		 * Defaults to CENTERED placement.
		 */
		connectorPlacement?: ConnectorPlacementType;
		/**
		 * Show an arrowhead at the destination end of the edge.
		 * Defaults to false.
		 */
		showArrowhead?: boolean;
	};
	/**
	 * Render Callbacks for rendering nodes, potential nodes, edges, panels,
	 * context menus, etc.
	 */
	renderCallbacks: RenderCallbacks<NodeType, EdgeType>;
	/**
	 * Action interceptor. Before any action is dispatched to the store,
	 * you may intercept and modify it or cancel it entirely.
	 * Please keep in mind that in case you implement an interceptor,
	 * you're responsible for dispatching the action.
	 *
	 * @example <caption>Logging an action</caption>
	 * const log = (action, dispatch, getState) => {
	 *   console.log(action);
	 *   dispatch(action);
	 * };
	 */
	actionInterceptor?: ActionInterceptor<NodeType, EdgeType>;
	/**
	 * Node Type Configuration. Optional.
	 * Useful for specifying overrides for connector placement or visible connectors.
	 * Also, useful for providing for size for potential nodes being dragged using the same type.
	 * Is required when using boundary connector placement to provide shapes for different
	 * node types.
	 */
	nodeTypeConfig?: {
		[typeId: string]: DiagramMakerNodeTypeConfiguration;
	};
}
declare class ConfigService<NodeType, EdgeType> {
	private config;
	constructor(config: DiagramMakerConfig<NodeType, EdgeType>);
	getRenderNode: () => (node: DiagramMakerNode<NodeType>, diagramMakerContainer: HTMLElement, consumerContainer?: void | HTMLElement | undefined) => (HTMLElement | undefined | void);
	getRenderEdge: () => ((edge: DiagramMakerEdge<EdgeType>, diagramMakerContainer: HTMLElement, consumerContainer?: void | HTMLElement | undefined) => (HTMLElement | undefined | void)) | undefined;
	getRenderPanel: (name: string) => (panel: DiagramMakerPanel, state: DiagramMakerData<NodeType, EdgeType>, diagramMakerContainer: HTMLElement, consumerContainer?: void | HTMLElement | undefined) => (HTMLElement | undefined | void);
	getRenderPotentialNode: () => ((node: DiagramMakerPotentialNode, diagramMakerContainer: HTMLElement, consumerContainer?: void | HTMLElement | undefined) => (HTMLElement | undefined | void)) | undefined;
	getRenderDestroy: () => DestroyCallback;
	getBoundRenderContextMenu: (type: string, id?: string | undefined) => BoundRenderCallback | undefined;
	getConnectorPlacement: () => ConnectorPlacementType;
	getShowArrowhead: () => boolean;
	getActionInterceptor: () => ActionInterceptor<NodeType, EdgeType> | undefined;
	getSizeForNodeType: (typeId: string) => Size | undefined;
	getConnectorPlacementForNodeType: (typeId: string) => ConnectorPlacementType;
	getShapeForNodeType: (typeId: string) => ShapeType | undefined;
	getVisibleConnectorTypesForNodeType: (typeId: string) => TypeForVisibleConnectorTypes | undefined;
	private getNodeTypeConfiguration;
	private getRenderContextMenu;
	private getRenderCallbacks;
}
declare class DiagramMakerApi<NodeType = {}, EdgeType = {}> {
	private store;
	constructor(store: Store<DiagramMakerData<NodeType, EdgeType>>);
	/**
	 * Arranges nodes according to the specified layout type.
	 *
	 * @param {LayoutConfig} layoutConfig - Layout type and its parameters.
	 * @returns {DiagramMakerApi} - Returns this `DiagramMakerApi` instance for method chaining.
	 *
	 * NOTE FOR "WORKFLOW" LAYOUT:
	 * "Workflow" layout uses Dagre library underneath:
	 * https://github.com/dagrejs/dagre
	 *
	 * We don't bundle it with DiagramMaker, as not all consumers need this functionality.
	 * To use "Workflow" layout, you'll need to add Dagre library to your package.json.
	 */
	layout(layoutConfig: LayoutConfig): DiagramMakerApi<NodeType, EdgeType>;
	/**
	 * Sets the editor to the given mode, in order to modify its UI behavior.
	 *
	 * @param {EditorModeType} mode - The mode to set the editor to.
	 * @returns {DiagramMakerApi} - Returns this `DiagramMakerApi` instance for method chaining.
	 */
	setEditorMode(mode: EditorModeType): DiagramMakerApi<NodeType, EdgeType>;
	/**
	 * Moves the workspace around to center the node matching the passed ID.
	 * Also selects the corresponding node.
	 *
	 * @param {string} nodeId - ID of the node to focus
	 * @param {number} [leftPanelWidth] - Width of the fixed left panel
	 * @param {number} [rightPanelWidth] - Width of the fixed right panel
	 * @returns {DiagramMakerApi} - Returns this `DiagramMakerApi` instance for method chaining.
	 */
	focusNode(nodeId: string, leftPanelWidth?: number, rightPanelWidth?: number): DiagramMakerApi<NodeType, EdgeType>;
	/**
	 * Moves the workspace around to center the selected node.
	 * If more than 1 nodes are selected, it falls back to fitting the selected nodes in.
	 * If no nodes are selected, this resets the zoom & centers the workspace.
	 *
	 * @param {number} [leftPanelWidth] - Width of the fixed left panel
	 * @param {number} [rightPanelWidth] - Width of the fixed right panel
	 * @returns {DiagramMakerApi} - Returns this `DiagramMakerApi` instance for method chaining.
	 */
	focusSelected(leftPanelWidth?: number, rightPanelWidth?: number): DiagramMakerApi<NodeType, EdgeType>;
	/**
	 * Zooms out & pans the workspace such that all nodes are visible in the screen.
	 *
	 * @param {number} [leftPanelWidth] - Width of the fixed left panel
	 * @param {number} [rightPanelWidth] - Width of the fixed right panel
	 * @param {string[]} [nodeKeys] - Optional. List of node IDs which need to be fit in the screen,
	 * Defaults to fitting all the nodes.
	 * @returns {DiagramMakerApi} - Returns this `DiagramMakerApi` instance for method chaining.
	 */
	fit(leftPanelWidth?: number, rightPanelWidth?: number, nodeKeys?: string[]): DiagramMakerApi<NodeType, EdgeType>;
	/**
	 * Zooms in one level into the diagram maker workspace at the center.
	 *
	 * @param {number} [zoom=50] - Zoom factor to zoom by
	 * @returns {DiagramMakerApi} - Returns this `DiagramMakerApi` instance for method chaining.
	 */
	zoomIn(zoom?: number): DiagramMakerApi<NodeType, EdgeType>;
	/**
	 * Zooms out one level into the diagram maker workspace at the center.
	 *
	 * @param {number} [zoom=50] - Zoom factor to zoom by
	 * @returns {DiagramMakerApi} - Returns this `DiagramMakerApi` instance for method chaining.
	 */
	zoomOut(zoom?: number): DiagramMakerApi<NodeType, EdgeType>;
	/**
	 * Resets the zoom to base level.
	 *
	 * @returns {DiagramMakerApi} - Returns this `DiagramMakerApi` instance for method chaining.
	 */
	resetZoom(): DiagramMakerApi<NodeType, EdgeType>;
	/**
	 * Undo the last undoable action.
	 *
	 * @returns {DiagramMakerApi} - Returns this `DiagramMakerApi` instance for method chaining.
	 */
	undo(): this;
	/**
	 * Redo the last undone action.
	 *
	 * @returns {DiagramMakerApi} - Returns this `DiagramMakerApi` instance for method chaining.
	 */
	redo(): this;
	/**
	 * dispatch a action, for plugin use
	 */
	dispatch(action: AnyAction): void;
	private workspaceZoom;
}
export declare type ObserverCallback = (...args: any[]) => void;
declare class Observer {
	private globalEventListeners;
	private events;
	subscribe: (event: string, callback: ObserverCallback) => void;
	subscribeAll: (callback: ObserverCallback) => void;
	publish: (event: string, payload?: any) => void;
	private hasEvent;
}
/**
 * Top Level DiagramMaker Class.
 * Instantiate to render a diagram maker instance within a container.
 * @class
 */
export declare class DiagramMaker<NodeType = {}, EdgeType = {}> {
	/**
	 * DiagramMaker store.
	 * Currently used for dispatching, fetching state & listening to updates.
	 * Will be moved to API and closed out.
	 */
	readonly store: Store<DiagramMakerData<NodeType, EdgeType>>;
	/**
	 * DiagramMaker APIs.
	 */
	readonly api: DiagramMakerApi<NodeType, EdgeType>;
	private config;
	private container;
	private actionDispatcher;
	private observer;
	private eventManager;
	constructor(domHandle: string | HTMLElement, config: DiagramMakerConfig<NodeType, EdgeType>, { initialData, consumerRootReducer, consumerEnhancer, eventListener, }?: {
		initialData?: DiagramMakerData<NodeType, EdgeType>;
		consumerRootReducer?: Reducer<DiagramMakerData<NodeType, EdgeType>, Action>;
		consumerEnhancer?: StoreEnhancer;
		eventListener?: ObserverCallback;
	});
	/**
	 * API called to update diagram maker about container size changes.
	 * Should be called when the window resizes or panels outside of diagram maker
	 * opening up to cause changes to container size.
	 *
	 * This is used for several calculations, so dragging & other interactions might be broken
	 * if this API is not called appropriately.
	 */
	updateContainer: () => void;
	/**
	 * API called to clean up a diagram maker instance after the user navigates away from the page
	 * or closes the workspace.
	 *
	 * This is used to clean up event handlers that diagram maker attaches to the container, so
	 * it could lead to a memory leak if its not called. This is because DOM & event listeners
	 * have a self loop so it never gets garbage collected automatically unless we remove the event
	 * listeners.
	 */
	destroy: () => void;
	private static getContainer;
}
export interface NormalizedTarget {
	originalTarget: HTMLElement;
	id?: string;
	type?: string;
}
declare enum ContainerEventType {
	DIAGRAM_MAKER_CONTAINER_UPDATE = "diagramMakerContainerUpdate"
}
declare enum MouseClickEventType {
	LEFT_CLICK = "click",
	RIGHT_CLICK = "contextmenu",
	MOUSE_DOWN = "mousedown",
	MOUSE_UP = "mouseup"
}
declare enum MouseMoveEventType {
	MOUSE_MOVE = "mousemove",
	MOUSE_OVER = "mouseover",
	MOUSE_OUT = "mouseout"
}
declare enum WheelEventType {
	MOUSE_WHEEL = "wheel"
}
declare enum WindowEventType {
	RESIZE = "resize"
}
declare enum DragEventType {
	DRAG_END = "__dragend",
	DRAG = "__drag",
	DRAG_START = "__dragstart"
}
declare enum DropEventType {
	DROP = "__drop",
	DRAG_ENTER = "__dragenter",
	DRAG_LEAVE = "__dragleave",
	DRAG_OVER = "__dragover"
}
declare enum KeyboardEventType {
	KEY_DOWN = "keydown",
	KEY_UP = "keyup",
	KEY_PRESS = "keypress"
}
export declare const Event: {
	KEY_DOWN: KeyboardEventType.KEY_DOWN;
	KEY_UP: KeyboardEventType.KEY_UP;
	KEY_PRESS: KeyboardEventType.KEY_PRESS;
	DROP: DropEventType.DROP;
	DRAG_ENTER: DropEventType.DRAG_ENTER;
	DRAG_LEAVE: DropEventType.DRAG_LEAVE;
	DRAG_OVER: DropEventType.DRAG_OVER;
	DRAG_END: DragEventType.DRAG_END;
	DRAG: DragEventType.DRAG;
	DRAG_START: DragEventType.DRAG_START;
	RESIZE: WindowEventType.RESIZE;
	MOUSE_WHEEL: WheelEventType.MOUSE_WHEEL;
	MOUSE_MOVE: MouseMoveEventType.MOUSE_MOVE;
	MOUSE_OVER: MouseMoveEventType.MOUSE_OVER;
	MOUSE_OUT: MouseMoveEventType.MOUSE_OUT;
	LEFT_CLICK: MouseClickEventType.LEFT_CLICK;
	RIGHT_CLICK: MouseClickEventType.RIGHT_CLICK;
	MOUSE_DOWN: MouseClickEventType.MOUSE_DOWN;
	MOUSE_UP: MouseClickEventType.MOUSE_UP;
};
declare enum MouseButton {
	LEFT = 0,
	MIDDLE = 1,
	RIGHT = 2,
	BROWSER_BACK = 3,
	BROWSER_FORWARD = 4
}
export interface NormalizedMouseMoveEvent {
	originalEvent: MouseEvent;
	position: Position;
	type: MouseMoveEventType;
}
export interface NormalizedMouseScrollEvent {
	delta: number;
	originalEvent: WheelEvent;
	position: Position;
	type: WheelEventType;
}
export interface NormalizedMouseHoverEvent {
	originalEvent: MouseEvent;
	target: NormalizedTarget;
	type: MouseMoveEventType;
}
export interface NormalizedMouseClickEvent {
	originalEvent: MouseEvent;
	button: MouseButton;
	position: Position;
	target: NormalizedTarget;
	offset: Position;
	type: MouseClickEventType;
}
export interface NormalizedDragEvent {
	position: Position;
	target: NormalizedTarget;
	offset?: Position;
	dragReference?: Position;
	type: DragEventType;
}
export interface NormalizedContainerEvent {
	contextRect: ClientRect | DOMRect;
	type: ContainerEventType;
}
export interface NormalizedWindowEvent {
	originalEvent: Event;
	size: Size;
	type: WindowEventType;
}
export interface NormalizedKeyboardEvent {
	code: string;
	key: string;
	ctrlKey: boolean;
	shiftKey: boolean;
	metaKey: boolean;
	modKey: boolean;
	originalEvent: KeyboardEvent;
	type: KeyboardEventType;
}
export declare type NormalizedEvent = NormalizedContainerEvent | NormalizedMouseMoveEvent | NormalizedDragEvent | NormalizedWindowEvent | NormalizedMouseScrollEvent | NormalizedMouseClickEvent | NormalizedKeyboardEvent | NormalizedMouseHoverEvent;
/**
 * Combine multiple reducers into one that will pipe `state` through the provided reducers one-by-one,
 * passing the result of the previous reducer as an input of the next one.
 *
 * Allows having `null` or `undefined` reducers in the list. They will be treated as identity function and will
 * pass the state forward without any modifications.
 */
export declare function sequenceReducers<StateType, ActionType extends AnyAction>(rootReducer: Reducer<StateType, ActionType>, ...reducers: (Reducer<StateType, ActionType> | undefined | null)[]): Reducer<StateType, ActionType>;
export declare class ActionDispatcher<NodeType, EdgeType> {
	private observer;
	private store;
	private config;
	private static getNormalizedPositionOffset;
	private static getNormalizedPositionOffsetInWorkspace;
	constructor(observer: Observer, store: Store<DiagramMakerData<NodeType, EdgeType>>, config: ConfigService<NodeType, EdgeType>);
	private subscribeToUIEvents;
	private createEventFilterCallback;
	private subscribeWithFilter;
	private handleLeftMouseClick;
	private handleMouseOver;
	private handleMouseOut;
	private handleDrag;
	private handleDragStart;
	private handleDragEnd;
	private handleWheelScroll;
	private handleDrop;
	private handleContainerUpdate;
	private handleRightMouseClick;
	private handleMouseDown;
	private handleKeyDown;
}